pub async fn count_with_slide_and_user_ids(
conn: &mut PgConnection,
exercise_slide_id: Uuid,
user_id: Uuid,
) -> ModelResult<u32>Expand description
How many live rejections a user has collected on a slide.
pub async fn count_with_slide_and_user_ids(
conn: &mut PgConnection,
exercise_slide_id: Uuid,
user_id: Uuid,
) -> ModelResult<u32>How many live rejections a user has collected on a slide.